@@ -10,7 +10,7 @@
 # ABSTRACT: Check the configuration of an application
 
 package App::Cme::Command::check ;
-$App::Cme::Command::check::VERSION = '1.005';
+$App::Cme::Command::check::VERSION = '1.007';
 use strict;
 use warnings;
 use 5.10.1;
@@ -29,7 +29,7 @@ sub opt_spec {
     my ( $class, $app ) = @_;
     return ( 
         [ "strict!" => "cme will exit 1 if warnings are found during check" ],
-        $class->global_options,
+        $class->cme_global_options,
     );
 }
 
@@ -76,7 +76,7 @@ App::Cme::Command::check - Check the configuration of an application
 
 =head1 VERSION
 
-version 1.005
+version 1.007
 
 =head1 SYNOPSIS
 
@@ -95,7 +95,12 @@ Example:
 
  cme check fstab
 
-Some applications will allow to override the default configuration file. For instance:
+Some applications allows one to override the default configuration file.
+For instance, with Debian copyright model, you can run cme on a different file:
+
+  cme check dpkg-copyright foobar
+
+or directly check copyright data on STDIN:
 
   curl http://metadata.ftp-master.debian.org/changelogs/main/f/frozen-bubble/unstable_copyright \
   | cme check dpkg-copyright -
