@@ -10,7 +10,7 @@
 # ABSTRACT: Dump the configuration of an application
 
 package App::Cme::Command::dump ;
-$App::Cme::Command::dump::VERSION = '1.006';
+$App::Cme::Command::dump::VERSION = '1.007';
 use strict;
 use warnings;
 use 5.10.1;
@@ -35,7 +35,7 @@ sub opt_spec {
                 default => 'custom'
             }
         ],
-        $class->global_options,
+        $class->cme_global_options,
     );
 }
 
@@ -76,7 +76,7 @@ App::Cme::Command::dump - Dump the configuration of an application
 
 =head1 VERSION
 
-version 1.006
+version 1.007
 
 =head1 SYNOPSIS
 
