@@ -10,7 +10,7 @@
 # ABSTRACT: Edit the configuration of an application
 
 package App::Cme::Command::edit ;
-$App::Cme::Command::edit::VERSION = '1.005';
+$App::Cme::Command::edit::VERSION = '1.007';
 use strict;
 use warnings;
 use 5.10.1;
@@ -31,7 +31,7 @@ sub opt_spec {
     return (
         [ "ui|if=s" => "user interface type. Either tk, curses, shell" ],
         [ "open-item=s" => "open a specific item of the configuration" ],
-        $class->global_options,
+        $class->cme_global_options,
     );
 }
 
@@ -130,7 +130,7 @@ App::Cme::Command::edit - Edit the configuration of an application
 
 =head1 VERSION
 
-version 1.005
+version 1.007
 
 =head1 SYNOPSIS
 
@@ -151,14 +151,14 @@ version 1.005
 
 =head1 DESCRIPTION
 
-Edit a configuration. By default, a Tk GUI will be opened If L<Config::Model::TkUI> is
+Edit a configuration. By default, a Tk GUI will be opened if C<Config::Model::TkUI> is
 installed. You can choose another user interface with the C<-ui> option:
 
 =over
 
 =item *
 
-C<tk>: provides a Tk graphical interface (If L<Config::Model::TkUI> is
+C<tk>: provides a Tk graphical interface (If C<Config::Model::TkUI> is
 installed).
 
 =item *
