@@ -10,7 +10,7 @@
 # ABSTRACT: Fix the configuration of an application
 
 package App::Cme::Command::fix ;
-$App::Cme::Command::fix::VERSION = '1.005';
+$App::Cme::Command::fix::VERSION = '1.007';
 use strict;
 use warnings;
 use 5.10.1;
@@ -31,14 +31,14 @@ sub opt_spec {
     return ( 
         [ "from=s@"  => "fix only a subset of a configuration tree" ],
         [ "filter=s" => "pattern to select the element name to be fixed"],
-        $class->global_options,
+        $class->cme_global_options,
     );
 }
 
 sub usage_desc {
   my ($self) = @_;
   my $desc = $self->SUPER::usage_desc; # "%c COMMAND %o"
-  return "$desc [application] [file | ~~ ]";
+  return "$desc [application] [ file ]";
 }
 
 sub description {
@@ -78,7 +78,7 @@ App::Cme::Command::fix - Fix the configuration of an application
 
 =head1 VERSION
 
-version 1.005
+version 1.007
 
 =head1 SYNOPSIS
 
@@ -120,7 +120,7 @@ Example:
 
 or 
 
- cme fix dpkg -filter Depend 
+ cme fix dpkg -filter Depend
 
 =back
 
