@@ -10,7 +10,7 @@
 # ABSTRACT: Edit the configuration of an application with fuse
 
 package App::Cme::Command::fusefs ;
-$App::Cme::Command::fusefs::VERSION = '1.004';
+$App::Cme::Command::fusefs::VERSION = '1.007';
 use strict;
 use warnings;
 use 5.10.1;
@@ -45,7 +45,7 @@ sub opt_spec {
         ],
         [ "dfuse!" => "debug fuse problems" ],
         [ "dir-char=s" => "string to replace '/' in configuration parameter names"],
-        $class->global_options,
+        $class->cme_global_options,
     );
 }
 
@@ -107,7 +107,7 @@ App::Cme::Command::fusefs - Edit the configuration of an application with fuse
 
 =head1 VERSION
 
-version 1.004
+version 1.007
 
 =head1 SYNOPSIS
 
