@@ -10,7 +10,7 @@
 # ABSTRACT: Migrate the configuration of an application
 
 package App::Cme::Command::migrate ;
-$App::Cme::Command::migrate::VERSION = '1.005';
+$App::Cme::Command::migrate::VERSION = '1.007';
 use strict;
 use warnings;
 use 5.10.1;
@@ -29,7 +29,7 @@ sub validate_args {
 sub opt_spec {
     my ( $class, $app ) = @_;
     return (
-        $class->global_options,
+        $class->cme_global_options,
     );
 }
 
@@ -68,7 +68,7 @@ App::Cme::Command::migrate - Migrate the configuration of an application
 
 =head1 VERSION
 
-version 1.005
+version 1.007
 
 =head1 SYNOPSIS
 
