@@ -10,7 +10,7 @@
 # ABSTRACT: Modify the configuration of an application
 
 package App::Cme::Command::modify ;
-$App::Cme::Command::modify::VERSION = '1.006';
+$App::Cme::Command::modify::VERSION = '1.007';
 use strict;
 use warnings;
 use 5.10.1;
@@ -32,7 +32,7 @@ sub opt_spec {
     my ( $class, $app ) = @_;
     return ( 
         [ "save!"     => "Force a save even if no change was done" ],
-        $class->global_options,
+        $class->cme_global_options,
     );
 }
 
@@ -71,7 +71,7 @@ App::Cme::Command::modify - Modify the configuration of an application
 
 =head1 VERSION
 
-version 1.006
+version 1.007
 
 =head1 SYNOPSIS
 
