@@ -10,7 +10,7 @@
 # ABSTRACT: Search the configuration of an application
 
 package App::Cme::Command::search ;
-$App::Cme::Command::search::VERSION = '1.006';
+$App::Cme::Command::search::VERSION = '1.007';
 use strict;
 use warnings;
 use 5.10.1;
@@ -36,7 +36,7 @@ sub opt_spec {
             "narrow-search=s" => "narrows down the search to element, value, key, summary, description or help",
             { regex => qr/^(?:element|value|key|summary|description|help|all)$/, default => 'all' }
         ],
-        $class->global_options,
+        $class->cme_global_options,
     );
 }
 
@@ -83,7 +83,7 @@ App::Cme::Command::search - Search the configuration of an application
 
 =head1 VERSION
 
-version 1.006
+version 1.007
 
 =head1 SYNOPSIS
 
