@@ -10,7 +10,7 @@
 # ABSTRACT: Edit the configuration of an application with a shell
 
 package App::Cme::Command::shell ;
-$App::Cme::Command::shell::VERSION = '1.005';
+$App::Cme::Command::shell::VERSION = '1.007';
 use strict;
 use warnings;
 use 5.10.1;
@@ -28,7 +28,7 @@ sub opt_spec {
     my ( $class, $app ) = @_;
     return ( 
         [ "open-item=s" => "open a specific item of the configuration" ],
-        $class->global_options,
+        $class->cme_global_options,
     );
 }
 
@@ -65,7 +65,7 @@ App::Cme::Command::shell - Edit the configuration of an application with a shell
 
 =head1 VERSION
 
-version 1.005
+version 1.007
 
 =head1 SYNOPSIS
 
