@@ -10,7 +10,7 @@
 # ABSTRACT: Update the configuration of an application
 
 package App::Cme::Command::update ;
-$App::Cme::Command::update::VERSION = '1.006';
+$App::Cme::Command::update::VERSION = '1.007';
 use strict;
 use warnings;
 use 5.10.1;
@@ -34,7 +34,7 @@ sub opt_spec {
         [ "edit!"     => "Run editor after update is done" ],
         [ "save!"     => "Force a save even if no change was done" ],
         [ "backup:s"  => "Create a backup of configuration files before saving." ],
-        $class->global_options,
+        $class->cme_global_options,
     );
 }
 
@@ -87,7 +87,7 @@ App::Cme::Command::update - Update the configuration of an application
 
 =head1 VERSION
 
-version 1.006
+version 1.007
 
 =head1 SYNOPSIS
 
